@@ -52,7 +52,6 @@
 #  define N_(String) (String)
 #endif
 
-typedef enum _SierraPacket SierraPacket;
 enum _SierraPacket {
 	NUL				= 0x00,
 	SIERRA_PACKET_DATA		= 0x02,
@@ -66,6 +65,7 @@ enum _SierraPacket {
 	SIERRA_PACKET_SESSION_ERROR	= 0xfc,
 	SIERRA_PACKET_SESSION_END	= 0xff
 };
+typedef enum _SierraPacket SierraPacket;
 
 /* Size of requested packet */
 #define SIERRA_PACKET_SIZE		32774
@@ -298,6 +298,8 @@ int sierra_check_battery_capacity (Camera *camera, GPContext *context)
 				     _("Cannot retrieve the battery capacity"));
 		return ret;
 	}
+	if (!capacity) /* 0% is unlikely */
+		return GP_OK;
 
 	if (capacity < 5) {
 		gp_context_error (context,
@@ -336,7 +338,7 @@ sierra_get_memory_left (Camera *camera, int *memory, GPContext *context)
 static int
 sierra_check_connection (Camera *camera, GPContext *context)
 {
-	int r = 0, timeout;
+	int r = 0, ret, timeout;
 	unsigned char c;
 
 	/* Only serial cameras close the connection after some timeout. */
@@ -352,9 +354,9 @@ sierra_check_connection (Camera *camera, GPContext *context)
 		 */
 		CHECK (gp_port_get_timeout (camera->port, &timeout));
 		CHECK (gp_port_set_timeout (camera->port, 20));
-		r = gp_port_read (camera->port, &c, 1);
+		ret = gp_port_read (camera->port, &c, 1);
 		CHECK (gp_port_set_timeout (camera->port, timeout));
-		switch (r) {
+		switch (ret) {
 		case GP_ERROR_TIMEOUT:
 		case GP_ERROR_IO_READ:
 
@@ -370,7 +372,7 @@ sierra_check_connection (Camera *camera, GPContext *context)
 			 * If any error (except timeout) has occurred, 
 			 * report it.
 			 */
-			CHECK (r);
+			CHECK (ret);
 		}
 
 		/*
@@ -522,6 +524,7 @@ sierra_read_packet (Camera *camera, unsigned char *packet, GPContext *context)
 	GP_DEBUG ("Reading packet...");
 
 	switch (camera->port->type) {
+	case GP_PORT_USB_SCSI:
 	case GP_PORT_USB:
 		blocksize = SIERRA_PACKET_SIZE;
 		break;
@@ -533,17 +536,17 @@ sierra_read_packet (Camera *camera, unsigned char *packet, GPContext *context)
 	}
 
 	/* Try several times before leaving on error... */
+	/* Clear the USB bus
+	   (what about the SERIAL bus : do we need to flush it?) */
+	sierra_clear_usb_halt(camera);
 	while (1) {
 
-		/* Clear the USB bus
-		   (what about the SERIAL bus : do we need to flush it?) */
-		sierra_clear_usb_halt(camera);
 
 		/*
 		 * Read data through the bus. If an error occurred,
 		 * try again.
 		 */
-		if (camera->port->type == GP_PORT_USB && (camera->pl->flags & SIERRA_WRAP_USB_MASK))
+		if ((camera->port->type == GP_PORT_USB_SCSI) && (camera->pl->flags & SIERRA_WRAP_USB_MASK))
 			result = usb_wrap_read_packet (camera->port,
 					(camera->pl->flags & SIERRA_WRAP_USB_MASK),
 					packet, blocksize);
@@ -560,6 +563,16 @@ sierra_read_packet (Camera *camera, unsigned char *packet, GPContext *context)
 			GP_DEBUG ("Retrying...");
 			continue;
 		}
+		if (result == 0) {
+			GP_DEBUG ("Read got 0 bytes.."); 
+			if (++r > 2) {
+				sierra_clear_usb_halt(camera);
+				GP_DEBUG ("Giving up...");
+				return GP_ERROR_IO_READ;
+			}
+			GP_DEBUG ("Retrying...");
+			continue;
+		}
 		br = result;
 
 		/*
@@ -997,7 +1010,8 @@ int sierra_sub_action (Camera *camera, SierraAction action, int sub_action,
 	CHECK (sierra_read_packet_wait (camera, buf, context));
 
 	switch (buf[0]) {
-		case SIERRA_PACKET_ENQ:
+	case ACK: /* reported on capture on Olympus 4040 */
+	case SIERRA_PACKET_ENQ:
 		return (GP_OK);
 	default:
 		gp_context_error (context, _("Received unexpected answer "
@@ -1231,7 +1245,7 @@ int sierra_get_string_register (Camera *camera, int reg, int fnumber,
 
 	if (file && total > min_progress_bytes) {
 		CHECK (gp_file_get_name(file, &file_name));
-		id = gp_context_progress_start (context, total, "%s", file_name);
+		id = gp_context_progress_start (context, total, _("Downloading data..."));
 	}
 
 	/* Read all the data packets */
@@ -1339,7 +1353,7 @@ sierra_capture (Camera *camera, CameraCaptureType type,
 {
 	int n, len = 0, r;
 	char filename[128];
-	const char *folder;
+	char *folder;
 	int timeout;
 
 	GP_DEBUG ("* sierra_capture");
