@@ -40,8 +40,10 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 #else
 			"no ltdl",
 #endif
-#ifdef HAVE_LIBUSB
-			"USB",
+#ifdef HAVE_LIBUSB1
+			"USB (libusb1)",
+#elif HAVE_LIBUSB
+			"USB (libusb0)",
 #else
 			"no USB",
 #endif
@@ -50,8 +52,6 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 
 #ifdef HAVE_RESMGR
 			"resmgr locking",
-#elif HAVE_BAUDBOY
-			"baudboy locking",
 #elif HAVE_TTYLOCK
 			"ttylock locking",
 #elif HAVE_LOCKDEV
@@ -95,11 +95,6 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 #else
 			"no resmgr (serial port access and locking)",
 #endif
-#ifdef HAVE_BAUDBOY
-			"baudboy (serial port locking)",
-#else
-			"no baudboy (serial port locking)",
-#endif
 #ifdef HAVE_TTYLOCK
 			"ttylock (serial port locking)",
 #else
